:tocdepth: 1

.. |grappelli| replace:: Grappelli
.. |filebrowser| replace:: FileBrowser

.. _changelog:

Changelog
=========

2.8.3 (not yet released)
------------------------

2.8.2 (September 28th 2016)
---------------------------

* Fixed: Constance templates.
* Fixed: Docs with template context processor.
* Fixed: Styling of select vertical/horizontal.
* Fixed: Wrong translations with index.html.
* Fixed: Translation of "Log in" with login template.
* Fixed: Removed loading url from future with smuggler.
* Improved: Docs on switch user with custom user model.
* Improved: Added universal distribute.
* Improved: Added some blocks around js hacks with change_form.html.
* Improved: Docs with DashboardModuleClass.
* Improved: Related widgets.

2.8.1 (March 7th, 2016)
-----------------------

* First release of Grappelli which is compatible with Django 1.9.
